@@ -3,15 +3,16 @@ import requests
 from taskhub.server import serve
 from retry import retry
 from loger import makelog
-
-address = "127.0.0.1"
+import traceback
 
 
 def sync(task):
-    back_end_url = ""
+    GRAB_KEY = "VooSb3VNims3IjaNxBERGvtdRpgecL2C"
+    back_end_url = "http://127.0.0.1/api/grab/web/data/"
     @retry(tries=5, delay=1, backoff=1)
-    def req(self, task: Task):
-        r = requests.post(back_end_url, json=task.get_dict())
+    def req(task):
+        print(task)
+        r = requests.post(back_end_url, json=task.get_dict(), headers={"GRAB-KEY":GRAB_KEY})
         r.raise_for_status
         return r.json()
 
@@ -22,7 +23,7 @@ def sync(task):
         makelog("sync: req 时发生异常：{}".format(traceback.format_exc()), 1)
         return False
     else:
-        if r_data.get("suc"):
+        if r_data.get("code") == 200:
             makelog("synced!", 4)
             return True
         else:
